@@ -175,3 +175,20 @@ class DysonPureCool(DysonPureCoolBase):
         else:
             oson = "OFF"
         self._set_configuration(oson=oson)
+
+
+class DysonPureCoolFormaldehyde(DysonPureCool):
+    """This model is compatible with PureCool but has one additional sensor."""
+
+    @property
+    def formaldehyde(self) -> Optional[int]:
+        """Return formaldehyde reading."""
+        # Dyson documentation for Dyson Pure Cool Formaldehyde refers to
+        # the formaldehyde reading as HCHO (pp5).
+        # https://www.dyson.com/content/dam/dyson/maintenance/user-guides/en_US/airtreatment/purifiers/TP09/497043-01.pdf
+        #
+        # H-CHO is also a common way to refer to formaldehyde.
+        #
+        # This is part of environmental data as per:
+        # https://github.com/seanrees/prometheus-dyson/issues/13#issue-923525150
+        return self._get_environmental_field_value("hcho")
