@@ -7,7 +7,7 @@ from libdyson import (
     DEVICE_TYPE_360_EYE,
     DEVICE_TYPE_360_HEURIST,
     DEVICE_TYPE_PURE_COOL,
-    DEVICE_TYPE_PURE_COOL_2021,
+    DEVICE_TYPE_PURE_COOL_FORMALDEHYDE,
     DEVICE_TYPE_PURE_COOL_DESK,
     DEVICE_TYPE_PURE_COOL_LINK,
     DEVICE_TYPE_PURE_COOL_LINK_DESK,
@@ -19,6 +19,7 @@ from libdyson import (
     Dyson360Heurist,
     DysonDevice,
     DysonPureCool,
+    DysonPureCoolFormaldehyde,
     DysonPureCoolLink,
     DysonPureHotCool,
     DysonPureHotCoolLink,
@@ -37,7 +38,7 @@ from . import CREDENTIAL, SERIAL
         (DEVICE_TYPE_PURE_COOL_LINK_DESK, DysonPureCoolLink),
         (DEVICE_TYPE_PURE_COOL_LINK, DysonPureCoolLink),
         (DEVICE_TYPE_PURE_COOL, DysonPureCool),
-        (DEVICE_TYPE_PURE_COOL_2021, DysonPureCool),
+        (DEVICE_TYPE_PURE_COOL_FORMALDEHYDE, DysonPureCoolFormaldehyde),
         (DEVICE_TYPE_PURE_COOL_DESK, DysonPureCool),
         (DEVICE_TYPE_PURE_HOT_COOL_LINK, DysonPureHotCoolLink),
         (DEVICE_TYPE_PURE_HOT_COOL, DysonPureHotCool),
